@@ -104,7 +104,7 @@ class StaticGenerator(object):
         
         """
         request = HttpRequest()
-        request.path = path
+        request.path_info = path
         request.META.setdefault('SERVER_PORT', 80)
         request.META.setdefault('SERVER_NAME', self.server_name)
         
